# importing modules
import sys as sys
import os 
import pandas as pd 
import matplotlib.pyplot as plt
# Getting the name of the directory where this file is present.
current = os.path.dirname(os.path.realpath(__file__))  # src
# Getting the parent directory name where the current directory is present.
parent = os.path.dirname(current) # Simulation
# Getting the grandparent directory name
gparent = os.path.dirname(parent) # RecruitmentSynchronization_SMCs
# The path where the plotExp.py is saved
mpath = gparent + '\\cellLib\\Scripts'
# appending a path
sys.path.append(mpath)
import plotExp
# The properties of traces
colors=plt.rcParams['axes.prop_cycle'].by_key()['color']
lines = ['-','--','-.',':']
markers = ['.',',','o','+','x','d']
# Figure file name and titles
figfiles=parent+'\\simFig2_2.png'
fig_title = 'The cytosolic calcium concentration in presence of noise \n with different standard deviation $\sigma $'
plot_title =['$Ca_i^{2+}$ concentration \n when $J_{PLC_{agonist}}= 0.06 \mu M/s$ ','$Ca_i^{2+}$ concentration \n when $J_{PLC_{agonist}}= 0.06 \mu M/s$',
'$Ca_i^{2+}$ concentration \n when $J_{PLC_{agonist}}= 0.08 \mu M/s$','$Ca_i^{2+}$ concentration \n when $J_{PLC_{agonist}}= 0.165 \mu M/s$']
labels = ['Original','$\sigma = 0.0025$','$\sigma = 0.003$']
# Data source
dfolder_original=parent+'\\originalData\\'
ofilenames=['Fig2_b_450.csv','Fig2_b.csv','Fig2_c.csv','Fig2_d.csv']
dfolder_sim=parent+'\\simulatedData\\'
nfilenames=[['simFig2_b_0.0025.csv','simFig2_b_0.0025.csv','simFig2_c_0.0025.csv','simFig2_d_0.0025.csv'],
['simFig2_b_0.003.csv','simFig2_b_0.003.csv','simFig2_c_0.003.csv','simFig2_d_0.003.csv'],
]
x_var_org ='x'
y_var_org ='Curve1'
x_var_sim = 't'
y_vars_sim = ['output/c_i','output/c_i','output/c_i', 'output/c_i']
x_label='t(s)'
y_label=['$c_{i}(\mu M)$','$c_{i}(\mu M)$','$c_{i}(\mu M)$','$c_{i}(\mu M)$']
# Build the traces
number_trace = 3
number_plot = len(y_vars_sim)
trace = [[0] * number_trace for i in range(number_plot)]    

for plotid, y_var_sim in enumerate(y_vars_sim):
   odata = pd.read_csv(dfolder_original+ofilenames[plotid])
   ox_data=odata[x_var_org].values
   oy_data=odata[y_var_org].values
   trace[plotid][0]={'dataX': ox_data, 'dataY': oy_data, 'lname': labels[0], 'linestyle':lines[1], 'marker':None, 'linecolor':colors[0],'y2':False}
   for traceid in range(number_trace-1): 
      dfilename_sim=dfolder_sim+nfilenames[traceid][plotid]
      data = pd.read_csv(dfilename_sim)
      x_data=data[x_var_sim].values   
      y_data=data[y_var_sim].values         
      trace[plotid][traceid+1]={'dataX': x_data, 'dataY': y_data, 'lname': labels[traceid+1], 'linestyle':lines[0], 'marker':None, 'linecolor':colors[traceid+1],'y2':False}
          
# Build the plots 
# maxH=8.75 inches, width 2.63-7.5
rows,cols = 2,2
left = 0.125  # the left side of the subplots of the figure,0.125
right = 0.9   # the right side of the subplots of the figure,0.9
bottom = 0.1  # the bottom of the subplots of the figure, 0.1
top = 0.75     # the top of the subplots of the figure 0.9
wspace = 0.4  # the amount of width reserved for space between subplots,
              # expressed as a fraction of the average axis width, 0.2
hspace = 0.7  # the amount of height reserved for space between subplots,
              # expressed as a fraction of the average axis height, 0.2
lgdfont, labelfont =10, 10
width, height= cols*3.5, rows*3
figs ={ 'width':width, 'height': height, 'rows': rows, 'cols': cols,'left':left,'bottom':bottom,'right':right,'top':top,'wspace': wspace,'hspace': hspace,'fig_title':fig_title,'title_y':1}

plots=[]
for id in range(4):    
   colid = id%2
   rowid = id//2
   if id == 0:
      lgdshow = True
      bbox_to_anchor = (2,1.7)
   else:
      lgdshow = False
      bbox_to_anchor = None
         
   iplot={'rowid':rowid, 'colid':colid, 'xlabel': x_label, 'ylabel':y_label[id], 'twiny':False,    'ylabel2':y_label[id],'labelcolor':colors[1],
            'lgdshow': lgdshow, 'lgdloc':'best', 'bbox_to_anchor':bbox_to_anchor,'lgdncol': 3, 'lgdfont':lgdfont, 'labelfont': labelfont,  
            'setxlim': False, 'xmin':0, 'xmax': 1, 'setylim': False,'ymin':0, 'ymax':1, 'grid': True,    'gridaxis': 'both', 'plot_title': plot_title[id],
            'traces':trace[id]
            }    
   plots.append(iplot)

ids = range(len(y_vars_sim))   
subfigs={ids: plots for ids, plots in zip(ids, plots)}
fig,axs=plotExp.plotExp(figs,subfigs,figfiles)




