# importing modules
import sys as sys
import os 
import pandas as pd 
import matplotlib.pyplot as plt
# Getting the name of the directory where this file is present.
current = os.path.dirname(os.path.realpath(__file__))  # src
# Getting the parent directory name where the current directory is present.
parent = os.path.dirname(current) # Simulation
# Getting the grandparent directory name
gparent = os.path.dirname(parent) # RecruitmentSynchronization_SMCs
# The path where the plotExp.py is saved
mpath = gparent + '\\cellLib\\Scripts'
# appending a path
sys.path.append(mpath)
import plotExp
# The properties of traces
colors=plt.rcParams['axes.prop_cycle'].by_key()['color']
lines = ['-','--','-.',':']
markers = ['.',',','o','+','x','d']
# Figure file name and titles
figfiles=parent+'\\simFig3.png'
fig_title = ''
plot_title =['$Ca^{2+}$ concentration in the cytosol and IP3','$Ca^{2+}$ concentration in the SR','Cell membrane potential','Open state probability of calcium \n activated potassium channels']
labels = ['Original','CellML']
# Data source
dfolder_original=parent+'\\originalData\\'
ofilenames=['Fig3a1.csv','Fig3b.csv','Fig3c.csv','Fig3d.csv','Fig3a2.csv']
dfilename_sim=parent+'\\simulatedData\\simFig3.csv'
x_var_org ='x'
y_var_org ='Curve1'
x_var_sim = 't'
y_vars_sim = ['output/c_i','output/s_i','output/v_i', 'output/w_i','output/I_i']
x_label='t(s)'
y_label=['$c_{i}, I_{i}(\mu M)$','$s_{i}(\mu M)$','$v_{i}(mV)$','$w_{i}$']
# Build the traces
number_trace = 2
number_plot = len(y_vars_sim)
trace = [[0] * number_trace for i in range(number_plot)]
data = pd.read_csv(dfilename_sim)
x_data=data[x_var_sim].values     

for plotid, y_var_sim in enumerate(y_vars_sim):
   odata = pd.read_csv(dfolder_original+ofilenames[plotid])
   ox_data=odata[x_var_org].values
   oy_data=odata[y_var_org].values   
   y_data=data[y_var_sim].values
   if plotid<4: 
      trace[plotid][0]={'dataX': ox_data, 'dataY': oy_data, 'lname': labels[0], 'linestyle':lines[1], 'marker':None, 'linecolor':colors[0],'y2':False}
      trace[plotid][1]={'dataX': x_data, 'dataY': y_data, 'lname': labels[1], 'linestyle':lines[0], 'marker':None, 'linecolor':colors[1],'y2':False}
   else:
      otrace={'dataX': ox_data, 'dataY': oy_data, 'lname': labels[0], 'linestyle':lines[1], 'marker':None, 'linecolor':colors[0],'y2':False}
      ntrace={'dataX': x_data, 'dataY': y_data, 'lname': labels[1], 'linestyle':lines[1], 'marker':None, 'linecolor':colors[1],'y2':False}
        
# Build the plots 
# maxH=8.75 inches, width 2.63-7.5
rows,cols = 2,2
left = 0.125  # the left side of the subplots of the figure,0.125
right = 0.9   # the right side of the subplots of the figure,0.9
bottom = 0.1  # the bottom of the subplots of the figure, 0.1
top = 0.75     # the top of the subplots of the figure 0.9
wspace = 0.4  # the amount of width reserved for space between subplots,
              # expressed as a fraction of the average axis width, 0.2
hspace = 0.6  # the amount of height reserved for space between subplots,
              # expressed as a fraction of the average axis height, 0.2
lgdfont, labelfont =10, 10
width, height= cols*3.5, rows*3
figs ={ 'width':width, 'height': height, 'rows': rows, 'cols': cols,'left':left,'bottom':bottom,'right':right,'top':top,'wspace': wspace,'hspace': hspace,'fig_title':fig_title,'title_y':1}

plots=[]
for id in range(4):    
   colid = id%2
   rowid = id//2
   if id == 0:
      lgdshow = True
      bbox_to_anchor = (1.8,1.6)
      trace[id].append(otrace)
      trace[id].append(ntrace)
   else:
      lgdshow = False
      bbox_to_anchor = None
         
   iplot={'rowid':rowid, 'colid':colid, 'xlabel': x_label, 'ylabel':y_label[id], 'twiny':False,    'ylabel2':y_label[id],'labelcolor':colors[1],
            'lgdshow': lgdshow, 'lgdloc':'best', 'bbox_to_anchor':bbox_to_anchor,'lgdncol': 2, 'lgdfont':lgdfont, 'labelfont': labelfont,  
            'setxlim': False, 'xmin':0, 'xmax': 1, 'setylim': False,'ymin':0, 'ymax':1, 'grid': True,    'gridaxis': 'both', 'plot_title': plot_title[id],
            'traces':trace[id]
            }    
   plots.append(iplot)

ids = range(len(y_vars_sim))   
subfigs={ids: plots for ids, plots in zip(ids, plots)}
fig,axs=plotExp.plotExp(figs,subfigs,figfiles)




